@@ -14,12 +14,8 @@
 gloss_format_words <- function(text, formatting) {
   if (formatting %in% style_options("i")) formatting <- "textit"
   if (formatting %in% style_options("b")) formatting <- "textbf"
-  split_line <- gloss_linesplit(text) %>%
-    purrr::map_chr(~ sprintf("\\%s{%s}", formatting, .x)) %>%
-    purrr::map_chr(~ ifelse(
-      stringr::str_detect(.x, " "),
-      sprintf("{%s}", .x),
-      .x)) %>%
+  split_line <- sprintf("\\%s{%s}", formatting, gloss_linesplit(text))
+  split_line <- ifelse(grepl(" ", split_line), sprintf("{%s}", split_line), split_line) |>
     paste(collapse = " ")
   gsub("\\s+", " ", split_line)
 }
@@ -40,14 +36,14 @@ gloss_list <- function(glist, listlabel = NULL) {
     cli::cli_abort(c("{.fun gloss_list} needs an object of class {.cls gloss}",
                      "please use {.fun as_gloss} or {.fun gloss_df} first."))
   }
-  output <- getOption("glossr.output", "latex")
+  output <- config$output
   clean_gloss <- unclass(glist)
   attr(clean_gloss, "data") <- NULL
 
   if (output == "latex") {
     llabel <- if (is.null(listlabel)) "" else sprintf("\\label{%s}", listlabel)
-    clean_gloss <- stringr::str_replace_all(clean_gloss, "\\\\ex", "\\\\a") %>%
-      stringr::str_remove_all("\\\\xe \\n") %>%
+    clean_gloss <- gsub("\\\\ex", "\\\\a", clean_gloss)
+    clean_gloss <- gsub("\\\\xe \\n", "", clean_gloss) |>
       paste(collapse = "\n")
     clean_gloss <- sprintf("\\pex%s %s \\xe \n", llabel, clean_gloss)
     new_gloss(attr(glist, "data"), clean_gloss)
@@ -62,8 +58,8 @@ gloss_list <- function(glist, listlabel = NULL) {
 #' @noRd
 #' @return Key for expex
 format_pdf <- function(level) {
-  format <- getOption(sprintf("glossr.format.%s", level))
-  if (is.null(format)) {
+  format <- config$format[[level]]
+  if (is.null(format) | format == "") {
     NULL
   } else if (format %in% style_options("i")) {
     "\\itshape"
@@ -73,3 +69,16 @@ format_pdf <- function(level) {
     NULL
   }
 }
+
+#' Convert from latex to Markdown
+#'
+#' @param string Character string
+#' @return formatted string
+#' @noRd
+latex2md <- function(string) {
+  string <- gsub(latex_tag("textsc"), "\\U\\1", string, perl=TRUE)
+  string <- gsub("\\\\O", "&#8709;", string)
+  string <- gsub("\\$\\\\(emptyset|varnothing)\\$", "&#8709;", string)
+
+  string
+}
