@@ -5,7 +5,8 @@ test_that("long string formating works", {
 })
 
 # test gloss_list ----
-glosses <- dplyr::select(glosses, -language)
+ok_columns <- colnames(glosses)[colnames(glosses) != "language"]
+glosses <- glosses[,ok_columns]
 test_that("gloss_list has the right class", {
   expect_error(gloss_list("not a gloss"))
   gl <- gloss_list(gloss_df(glosses))
@@ -14,20 +15,21 @@ test_that("gloss_list has the right class", {
 })
 
 test_that("gloss_list renders properly with leipzig", {
-  options("glossr.output" = "leipzig")
+  config$output <- "leipzig"
   from_glosses <- gloss_df(glosses)
   gl <- gloss_list(from_glosses)
   expect_identical(gl[[1]], from_glosses[[1]])
 })
 
 test_that("gloss_list renders properly with latex", {
-  options("glossr.output" = "latex")
+  config$output <-  "latex"
   from_glosses <- gloss_df(glosses)
   gl <- gloss_list(from_glosses)
   for (gloss_item in from_glosses) {
-    as_re <- gsub("\\\\ex", "\\\\a", gloss_item) %>%
-      gsub(pattern = "\\\\xe \\n", replacement = "") %>%
+    as_re <- gsub("\\\\ex", "\\\\a", gloss_item) |>
+      gsub(pattern = "\\\\xe \\n", replacement = "") |>
       gsub(pattern = "([\\{\\(])", replacement = "\\\\\\1")
     expect_match(gl[[1]], as_re)
   }
 })
+
